==> haskell-neat-interpolation-0.3.2.2-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.2
id: neat-interpolation-0.3.2.2-3Kfi0x9K5uA9ERiScIy1uq
key: neat-interpolation-0.3.2.2-3Kfi0x9K5uA9ERiScIy1uq
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 83b4aaecce3b7b3436153a1e971d2bdf
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.4.3/site-local/neat-interpolation-0.3.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/neat-interpolation-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/neat-interpolation-0.3.2.2
hs-libraries: HSneat-interpolation-0.3.2.2-3Kfi0x9K5uA9ERiScIy1uq
depends:
    text-1.2.3.0 megaparsec-6.5.0-EOdm02h4sdCFcHfmPoA6xU
    template-haskell-2.13.0.0 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    base-4.11.1.0
abi-depends: text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             megaparsec-6.5.0-EOdm02h4sdCFcHfmPoA6xU=f15b63fc4d597deb03cc96e26ad0c981
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.3.2.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.2
id: neat-interpolation-0.3.2.2-1qKajjXnCunB59VcHa7VW3
key: neat-interpolation-0.3.2.2-1qKajjXnCunB59VcHa7VW3
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 004c3793f02fc0bd69bc3345b1b8566b
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.2/site-local/neat-interpolation-0.3.2.2
library-dirs: /usr/lib/ghc-8.6.2/site-local/neat-interpolation-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/neat-interpolation-0.3.2.2
hs-libraries: HSneat-interpolation-0.3.2.2-1qKajjXnCunB59VcHa7VW3
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-6.5.0-EUmv2cuuzifJ0XtF7esHmy template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
